@@ -1,14 +1,12 @@
 """
 originally from http://www.djangosnippets.org/snippets/828/ by dnordberg
 """
+import logging
+from optparse import make_option
 
-from six.moves import input
 from django.conf import settings
 from django.core.management.base import CommandError, BaseCommand
-import django
-import logging
-import re
-from optparse import make_option
+from six.moves import input
 
 
 class Command(BaseCommand):
@@ -27,32 +25,13 @@ class Command(BaseCommand):
                     help='Use another password for the database then defined in settings.py'),
         make_option('-D', '--dbname', action='store',
                     dest='dbname', default=None,
-                    help='Use another database name then defined in settings.py (For PostgreSQL this defaults to "template1")'),
+                    help='Use another database name then defined in settings.py'),
         make_option('-R', '--router', action='store',
-                    dest='router', default=None,
+                    dest='router', default='default',
                     help='Use this router-database other then defined in settings.py'),
     )
     help = "Resets the database for this project."
 
-    def set_db_settings(self, *args, **options):
-        if django.get_version() >= "1.2":
-            router = options.get('router')
-            if router is None:
-                return False
-
-            # retrieve this with the 'using' argument
-            dbinfo = settings.DATABASES.get(router)
-            settings.DATABASE_ENGINE = dbinfo.get('ENGINE').split('.')[-1]
-            settings.DATABASE_USER = dbinfo.get('USER')
-            settings.DATABASE_PASSWORD = dbinfo.get('PASSWORD')
-            settings.DATABASE_NAME = dbinfo.get('NAME')
-            settings.DATABASE_HOST = dbinfo.get('HOST')
-            settings.DATABASE_PORT = dbinfo.get('PORT')
-            return True
-        else:
-            # settings are set for django < 1.2 no modification needed
-            return True
-
     def handle(self, *args, **options):
         """
         Resets the database for this project.
@@ -60,12 +39,21 @@ class Command(BaseCommand):
         Note: Transaction wrappers are in reverse as a work around for
         autocommit, anybody know how to do this the right way?
         """
+        router = options.get('router')
+        dbinfo = settings.DATABASES.get(router)
+        if dbinfo is None:
+            raise CommandError("Unknown database router %s" % router)
 
-        if django.get_version() >= "1.2":
-            got_db_settings = self.set_db_settings(*args, **options)
-            if not got_db_settings:
-                raise CommandError("You are using Django %s which requires to specify the db-router.\nPlease specify the router by adding --router=<routername> to this command." % django.get_version())
-                return
+        engine = dbinfo.get('ENGINE').split('.')[-1]
+        user = options.get('user') or dbinfo.get('USER')
+        password = options.get('password') or dbinfo.get('PASSWORD')
+
+        database_name = options.get('dbname') or dbinfo.get('NAME')
+        if database_name == '':
+            raise CommandError("You need to specify DATABASE_NAME in your Django settings file.")
+
+        database_host = dbinfo.get('HOST')
+        database_port = dbinfo.get('PORT')
 
         verbosity = int(options.get('verbosity', 1))
         if options.get('interactive'):
@@ -75,7 +63,7 @@ This will IRREVERSIBLY DESTROY
 ALL data in the database "%s".
 Are you sure you want to do this?
 
-Type 'yes' to continue, or 'no' to cancel: """ % (settings.DATABASE_NAME,))
+Type 'yes' to continue, or 'no' to cancel: """ % (database_name,))
         else:
             confirm = 'yes'
 
@@ -83,71 +71,57 @@ Type 'yes' to continue, or 'no' to cancel: """ % (settings.DATABASE_NAME,))
             print("Reset cancelled.")
             return
 
-        postgis = re.compile('.*postgis')
-        engine = settings.DATABASE_ENGINE
-        user = options.get('user', settings.DATABASE_USER)
-        if user is None:
-            user = settings.DATABASE_USER
-        password = options.get('password', settings.DATABASE_PASSWORD)
-        if password is None:
-            password = settings.DATABASE_PASSWORD
-
         if engine in ('sqlite3', 'spatialite'):
             import os
             try:
                 logging.info("Unlinking %s database" % engine)
-                os.unlink(settings.DATABASE_NAME)
+                os.unlink(database_name)
             except OSError:
                 pass
-        elif engine == 'mysql':
+
+        elif engine in ('mysql',):
             import MySQLdb as Database
             kwargs = {
                 'user': user,
                 'passwd': password,
             }
-            if settings.DATABASE_HOST.startswith('/'):
-                kwargs['unix_socket'] = settings.DATABASE_HOST
+            if database_host.startswith('/'):
+                kwargs['unix_socket'] = database_host
             else:
-                kwargs['host'] = settings.DATABASE_HOST
-            if settings.DATABASE_PORT:
-                kwargs['port'] = int(settings.DATABASE_PORT)
+                kwargs['host'] = database_host
+
+            if database_port:
+                kwargs['port'] = int(database_port)
 
             connection = Database.connect(**kwargs)
-            drop_query = 'DROP DATABASE IF EXISTS `%s`' % settings.DATABASE_NAME
+            drop_query = 'DROP DATABASE IF EXISTS `%s`' % database_name
             utf8_support = options.get('no_utf8_support', False) and '' or 'CHARACTER SET utf8'
-            create_query = 'CREATE DATABASE `%s` %s' % (settings.DATABASE_NAME, utf8_support)
+            create_query = 'CREATE DATABASE `%s` %s' % (database_name, utf8_support)
             logging.info('Executing... "' + drop_query + '"')
             connection.query(drop_query)
             logging.info('Executing... "' + create_query + '"')
             connection.query(create_query)
 
-        elif engine == 'postgresql' or engine == 'postgresql_psycopg2' or postgis.match(engine):
+        elif engine in ('postgresql', 'postgresql_psycopg2', 'postgis'):
             if engine == 'postgresql':
                 import psycopg as Database  # NOQA
-            elif engine == 'postgresql_psycopg2' or postgis.match(engine):
+            elif engine in ('postgresql_psycopg2', 'postgis'):
                 import psycopg2 as Database  # NOQA
 
-            if settings.DATABASE_NAME == '':
-                from django.core.exceptions import ImproperlyConfigured
-                raise ImproperlyConfigured("You need to specify DATABASE_NAME in your Django settings file.")
-
-            database_name = options.get('dbname', 'template1')
-            if options.get('dbname') is None:
-                database_name = 'template1'
             conn_string = "dbname=%s" % database_name
-            if settings.DATABASE_USER:
+            if user:
                 conn_string += " user=%s" % user
-            if settings.DATABASE_PASSWORD:
+            if password:
                 conn_string += " password='%s'" % password
-            if settings.DATABASE_HOST:
-                conn_string += " host=%s" % settings.DATABASE_HOST
-            if settings.DATABASE_PORT:
-                conn_string += " port=%s" % settings.DATABASE_PORT
+            if database_host:
+                conn_string += " host=%s" % database_host
+            if database_port:
+                conn_string += " port=%s" % database_port
 
             connection = Database.connect(conn_string)
             connection.set_isolation_level(0)  # autocommit false
             cursor = connection.cursor()
-            drop_query = 'DROP DATABASE %s' % settings.DATABASE_NAME
+            drop_query = 'DROP DATABASE %s;' % database_name
             logging.info('Executing... "' + drop_query + '"')
 
             try:
@@ -155,18 +129,18 @@ Type 'yes' to continue, or 'no' to cancel: """ % (settings.DATABASE_NAME,))
             except Database.ProgrammingError as e:
                 logging.info("Error: %s" % str(e))
 
-            # Encoding should be SQL_ASCII (7-bit postgres default) or prefered UTF8 (8-bit)
-            create_query = "CREATE DATABASE %s" % settings.DATABASE_NAME
-            if settings.DATABASE_USER:
-                create_query += " WITH OWNER = %s " % settings.DATABASE_USER
+            create_query = "CREATE DATABASE %s" % database_name
+            create_query += " WITH OWNER = %s " % user
             create_query += " ENCODING = 'UTF8'"
 
-            if postgis.match(engine):
+            if engine == 'postgis':
                 create_query += ' TEMPLATE = template_postgis'
+
             if settings.DEFAULT_TABLESPACE:
                 create_query += ' TABLESPACE = %s;' % settings.DEFAULT_TABLESPACE
             else:
                 create_query += ';'
+
             logging.info('Executing... "' + create_query + '"')
             cursor.execute(create_query)
 
